@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
 our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.67'; # VERSION
+our $VERSION = '0.68'; # VERSION
 
 use 5.010001;
 use strict;
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.67 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-01-22.
+This document describes version 0.68 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2016-01-22.
 
 =head1 DESCRIPTION
 
@@ -378,11 +378,11 @@ Result:
    {
      logs => [
                {
-                 file    => "/home/u1/perl5/perlbrew/perls/perl-5.22.0/lib/site_perl/5.22.0/Perinci/Access/Schemeless.pm",
+                 file    => "/home/s1/perl5/perlbrew/perls/perl-5.22.0/lib/site_perl/5.22.0/Perinci/Access/Schemeless.pm",
                  func    => "Perinci::Access::Schemeless::action_call",
                  line    => 494,
                  package => "Perinci::Access::Schemeless",
-                 time    => 1453409840,
+                 time    => 1453476303,
                  type    => "create",
                },
              ],
@@ -583,7 +583,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Ex
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
 
 =head1 BUGS
 
