@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
 our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.67'; # VERSION
+our $VERSION = '0.68'; # VERSION
 
 use 5.010;
 use strict;
@@ -19,14 +19,21 @@ This package contains functions that demonstrate streaming input/output.
 _
 };
 
-$SPEC{nat} = {
+$SPEC{produce_ints} = {
     v => 1.1,
-    summary => 'This function produces a stream of natural numbers',
+    summary => 'This function produces a stream of integers, starting from 1',
+    tags => ['category:streaming-result'],
     args => {
         num => {
             summary => 'Limit number of numbers to produce',
+            description => <<'_',
+
+The default is to produce an infinite number.
+
+_
             schema => 'int*',
             cmdline_aliases => {n=>{}},
+            pos => 0,
         },
     },
     result => {
@@ -34,7 +41,7 @@ $SPEC{nat} = {
         schema => 'int*',
     },
 };
-sub nat {
+sub produce_ints {
     my %args = @_;
     my $i = 1;
     my $num = $args{num};
@@ -44,14 +51,58 @@ sub nat {
      }];
 }
 
-$SPEC{word} = {
+$SPEC{count_ints} = {
+    v => 1.1,
+    summary => 'This function accepts a stream of integers and return the number of integers input',
+    tags => ['category:streaming-input'],
+    args => {
+        input => {
+            summary => 'Number',
+            schema => 'int*',
+            stream => 1,
+            cmdline_src => 'stdin_or_files',
+        },
+    },
+};
+sub count_ints {
+    my %args = @_;
+    my $input = $args{input};
+    my $n = 0;
+    $n++ while defined $input->();
+    [200, "OK", "You input $n int(s)"];
+}
+
+$SPEC{count_lines} = {
+    v => 1.1,
+    summary => 'Count number of lines in the input',
+    tags => ['category:streaming-input'],
+    args => {
+        input => {
+            summary => 'Input',
+            schema => 'str*',
+            stream => 1,
+            cmdline_src => 'stdin_or_files',
+        },
+    },
+};
+sub count_lines {
+    my %args = @_;
+    my $input = $args{input};
+    my $n = 0;
+    $n++ while defined $input->();
+    [200, "OK", "Input is $n line(s)"];
+}
+
+$SPEC{produce_words} = {
     v => 1.1,
     summary => 'This function produces a stream of random words',
+    tags => ['category:streaming-result'],
     args => {
         num => {
             summary => 'Limit number of words to produce',
             schema => 'int*',
             cmdline_aliases => {n=>{}},
+            pos => 0,
         },
     },
     result => {
@@ -59,7 +110,7 @@ $SPEC{word} = {
         schema => ['str*', match=>'\A\w+\z'],
     },
 };
-sub word {
+sub produce_words {
     my %args = @_;
     my $i = 1;
     my $num = $args{num};
@@ -70,9 +121,10 @@ sub word {
      }];
 }
 
-$SPEC{word_err} = {
+$SPEC{produce_words_err} = {
     v => 1.1,
-    summary => 'Like word(), but 1 in every 10 words will be a non-word (which fails result schema)',
+    summary => 'Like `produce_words()`, but 1 in every 10 words will be a non-word (which fails the result schema)',
+    tags => ['categoryr:streaming-result'],
     args => {
         num => {
             summary => 'Limit number of words to produce',
@@ -85,7 +137,7 @@ $SPEC{word_err} = {
         schema => ['str*', match=>'\A\w+\z'],
     },
 };
-sub word_err {
+sub produce_words_err {
     my %args = @_;
     my $i = 1;
     my $num = $args{num};
@@ -99,9 +151,10 @@ sub word_err {
      }];
 }
 
-$SPEC{num_words} = {
+$SPEC{count_words} = {
     v => 1.1,
     summary => 'This function receives a stream of words and return the number of words',
+    tags => ['category:streaming-input'],
     description => <<'_',
 
 Input validation will check that each record from the stream is a word.
@@ -115,7 +168,7 @@ _
         },
     },
 };
-sub num_words {
+sub count_words {
     my %args = @_;
 
     my $words = $args{words};
@@ -126,13 +179,14 @@ sub num_words {
     [200, "OK", $num];
 }
 
-$SPEC{hash_stream} = {
+$SPEC{produce_hashes} = {
     v => 1.1,
     summary => 'This function produces a stream of hashes',
     args => {
         num => {
             schema => 'int*',
             cmdline_aliases => {n=>{}},
+            pos => 0,
         },
     },
     result => {
@@ -140,7 +194,7 @@ $SPEC{hash_stream} = {
         schema => 'hash*',
     },
 };
-sub hash_stream {
+sub produce_hashes {
     my %args = @_;
     my $num = $args{num};
 
@@ -151,9 +205,10 @@ sub hash_stream {
      }];
 }
 
-$SPEC{square_input} = {
+$SPEC{square_nums} = {
     v => 1.1,
     summary => 'This function squares its stream input',
+    tags => ['category:streaming-input', 'category:streaming-result'],
     args => {
         input => {
             req => 1,
@@ -167,7 +222,7 @@ $SPEC{square_input} = {
         schema => 'float*',
     },
 };
-sub square_input {
+sub square_nums {
     my %args = @_;
     my $input = $args{input};
 
@@ -178,9 +233,10 @@ sub square_input {
      }];
 }
 
-$SPEC{square_input_from_file} = {
+$SPEC{square_nums_from_file} = {
     v => 1.1,
     summary => 'This function squares its stream input',
+    tags => ['category:streaming-input', 'category:streaming-result'],
     args => {
         input => {
             req => 1,
@@ -195,13 +251,14 @@ $SPEC{square_input_from_file} = {
         schema => 'float*',
     },
 };
-sub square_input_from_file {
+sub square_nums_from_file {
     goto &square_input;
 }
 
-$SPEC{square_input_from_stdin} = {
+$SPEC{square_nums_from_stdin} = {
     v => 1.1,
     summary => 'This function squares its stream input',
+    tags => ['category:streaming-input', 'category:streaming-result'],
     args => {
         input => {
             req => 1,
@@ -216,13 +273,14 @@ $SPEC{square_input_from_stdin} = {
         schema => 'float*',
     },
 };
-sub square_input_from_stdin {
+sub square_nums_from_stdin {
     goto &square_input;
 }
 
-$SPEC{square_input_from_stdin_or_file} = {
+$SPEC{square_nums_from_stdin_or_file} = {
     v => 1.1,
     summary => 'This function squares its stream input',
+    tags => ['category:streaming-input', 'category:streaming-result'],
     args => {
         input => {
             req => 1,
@@ -237,19 +295,21 @@ $SPEC{square_input_from_stdin_or_file} = {
         schema => 'float*',
     },
 };
-sub square_input_from_stdin_or_file {
+sub square_nums_from_stdin_or_file {
     goto &square_input;
 }
 
 $SPEC{wc} = {
     v => 1.1,
     summary => 'Count the number of lines/words/characters of input, like the "wc" command',
+    tags => ['category:streaming-input'],
     args => {
         input => {
             req => 1,
             stream => 1,
             schema => 'str*',
             cmdline_src => 'stdin_or_files',
+            'cmdline.chomp' => 0,
         },
     },
     result => {
@@ -272,6 +332,7 @@ sub wc {
 $SPEC{wc_keys} = {
     v => 1.1,
     summary => 'Count the number of keys of each hash',
+    tags => ['category:streaming-input'],
     description => <<'_',
 
 This is a simple demonstration of accepting a stream of hashes. In command-line
@@ -316,7 +377,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.67 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-22.
+This document describes version 0.68 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-22.
 
 =head1 DESCRIPTION
 
@@ -326,9 +387,9 @@ This package contains functions that demonstrate streaming input/output.
 =head1 FUNCTIONS
 
 
-=head2 hash_stream(%args) -> [status, msg, result, meta]
+=head2 count_ints(%args) -> [status, msg, result, meta]
 
-This function produces a stream of hashes.
+This function accepts a stream of integers and return the number of integers input.
 
 This function is not exportable.
 
@@ -336,7 +397,9 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<num> => I<int>
+=item * B<input> => I<int>
+
+Number.
 
 =back
 
@@ -349,12 +412,12 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value:  (hash)
+Return value:  (any)
 
 
-=head2 nat(%args) -> [status, msg, result, meta]
+=head2 count_lines(%args) -> [status, msg, result, meta]
 
-This function produces a stream of natural numbers.
+Count number of lines in the input.
 
 This function is not exportable.
 
@@ -362,9 +425,9 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<num> => I<int>
+=item * B<input> => I<str>
 
-Limit number of numbers to produce.
+Input.
 
 =back
 
@@ -377,10 +440,10 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value:  (int)
+Return value:  (any)
 
 
-=head2 num_words(%args) -> [status, msg, result, meta]
+=head2 count_words(%args) -> [status, msg, result, meta]
 
 This function receives a stream of words and return the number of words.
 
@@ -408,7 +471,119 @@ that contains extra information.
 Return value:  (any)
 
 
-=head2 square_input(%args) -> [status, msg, result, meta]
+=head2 produce_hashes(%args) -> [status, msg, result, meta]
+
+This function produces a stream of hashes.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (hash)
+
+
+=head2 produce_ints(%args) -> [status, msg, result, meta]
+
+This function produces a stream of integers, starting from 1.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+Limit number of numbers to produce.
+
+The default is to produce an infinite number.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (int)
+
+
+=head2 produce_words(%args) -> [status, msg, result, meta]
+
+This function produces a stream of random words.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+Limit number of words to produce.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (str)
+
+
+=head2 produce_words_err(%args) -> [status, msg, result, meta]
+
+Like `produce_words()`, but 1 in every 10 words will be a non-word (which fails the result schema).
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+Limit number of words to produce.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (str)
+
+
+=head2 square_nums(%args) -> [status, msg, result, meta]
 
 This function squares its stream input.
 
@@ -434,7 +609,7 @@ that contains extra information.
 Return value:  (float)
 
 
-=head2 square_input_from_file(%args) -> [status, msg, result, meta]
+=head2 square_nums_from_file(%args) -> [status, msg, result, meta]
 
 This function squares its stream input.
 
@@ -460,7 +635,7 @@ that contains extra information.
 Return value:  (float)
 
 
-=head2 square_input_from_stdin(%args) -> [status, msg, result, meta]
+=head2 square_nums_from_stdin(%args) -> [status, msg, result, meta]
 
 This function squares its stream input.
 
@@ -486,7 +661,7 @@ that contains extra information.
 Return value:  (float)
 
 
-=head2 square_input_from_stdin_or_file(%args) -> [status, msg, result, meta]
+=head2 square_nums_from_stdin_or_file(%args) -> [status, msg, result, meta]
 
 This function squares its stream input.
 
@@ -566,69 +741,13 @@ that contains extra information.
 
 Return value:  (hash)
 
-
-=head2 word(%args) -> [status, msg, result, meta]
-
-This function produces a stream of random words.
-
-This function is not exportable.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<num> => I<int>
-
-Limit number of words to produce.
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (str)
-
-
-=head2 word_err(%args) -> [status, msg, result, meta]
-
-Like word(), but 1 in every 10 words will be a non-word (which fails result schema).
-
-This function is not exportable.
-
-Arguments ('*' denotes required arguments):
-
-=over 4
-
-=item * B<num> => I<int>
-
-Limit number of words to produce.
-
-=back
-
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
-Return value:  (str)
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
 
 =head1 BUGS
 
